Package {impARI}


Type: Package
Title: Improving Permutation-Based All-Resolutions Inference ('impARI')
Version: 0.0.3
Date: 2026-05-20
Description: The goal is to improve a permutation-based approach (R package: 'pARI') for simultaneous inference on the true discovery proportion by a branch-and-bound algorithm. It is designed to return a list with a bracketing for the true discovery proportion, rather than a single lower bound from 'pARI'. For more details see Andreella. A (2023) <doi:10.1002/sim.9725>.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Imports: Rcpp (≥ 1.0.12)
LinkingTo: Rcpp,RcppArmadillo
NeedsCompilation: yes
Packaged: 2026-05-21 04:04:43 UTC; ningn
Author: Ningning Xu [aut, cre]
Maintainer: Ningning Xu <ningningxu312@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-23 11:20:08 UTC

Improving Permutation-Based All-Resolutions Inference ('impARI')

Description

The goal is to improve a permutation-based approach (R package: 'pARI') for simultaneous inference on the true discovery proportion by a branch-and-bound algorithm. It is designed to return a list with a bracketing for the true discovery proportion, rather than a single lower bound from 'pARI'. For more details see Andreella. A, et.al (2023) <doi:10.1002/sim.9725>.

Arguments

pmat

P-value matrix where columns represent the m variables and rows the w permutations.

set

Integer vector which expresses the index set of features of interest.

maxit

Integer to specify the maximum number of iterations for branch and bound.

family

String character. Name of the family confidence envelope to compute the critical vector from "simes", "aorc", "beta", "higher.criticism", and "power". "simes" is with fast computational tricks.

delta

Non-negative integer \delta value.

alpha

Significance level between 0 and 1.

goleft

Boolean variable to decide which direction to go in branch and bound algorihtm, the default is go left first, i.e. the subspace to force a feature in.

Details

The main function in the package is impARI:

impARI(pmat, set, maxit, family, delta, alpha)

Value

by default returns a list with the following objects:

TD

lower bound for the number of true discoveries in the set selected

TD_heuristic

heuristic lower bound for the number of true discoveries in the set selected

TDP

lower true discovery proportion of true discoveries in the set selected

iter

the number of iterations at the end point, either iter< maxit when the procedure is converged or iter = maxit

Queue

queue of non-calculated child spaces in branch and bound algorihtm.

Author(s)

Ningning Xu, ningningxu312@gmail.com.

Maintainer: Ningning Xu <ningningxu312@gmail.com>

References

Andreella, A., Hemerik, J., Finos, L., Weeda, W., & Goeman, J. (2023). Permutation-based true discovery proportions for functional magnetic resonance imaging cluster analysis. Statistics in Medicine.

Rosenblatt, J. D., Finos, L., W., W. D., Solari, A., and Goeman, J. J. (2018). All-resolutions inference for brain imaging. NeuroImage, 181:786-796.

Hemerik, J., Solari, A., and Goeman, J. J. (2019). Permutation-based simultaneous confidence bounds for the false discovery proportion. Biometrika, 106(3):635-649.

Examples

  #### example
# simulated data ----------------------------------------------------------
m = 10  # features
B = 100 # permutations
set.seed(123)
# create a p-value matrix with m features as columns and B permutations as rows
pmat <- matrix(runif(m * B), nrow = B, ncol = m)
# print(p_value_matrix)

## set of interest
set_interest =  1:m

res = impARI(pmat = pmat, set = set_interest, maxit = 10, family = "simes", delta = 0, alpha=0.05)
res